@@ -26,18 +26,18 @@ var languageNames = {
 "fr": "French",
 "gl": "Galician",
 "ka": "Georgian",
-"de": "German",
-"el": "Greek",
+"de": "Almanca",
+"el": "Yunanca",
 "gu": "Gujarati",
-"he": "Hebrew",
-"hi": "Hindi",
-"hu": "Hungarian",
-"id": "Indonesian",
-"is": "Icelandic",
-"it": "Italian",
-"ja": "Japanese",
-"km": "Khmer",
-"ko": "Korean",
+"he": "İbranice",
+"hi": "Hintçe",
+"hu": "Macarca",
+"id": "Endonezce",
+"is": "İzlandaca",
+"it": "İtalyanca",
+"ja": "Japonca",
+"km": "Kmerce",
+"ko": "Korece",
 "lo": "Lao",
 "lv": "Latvian",
 "lt": "Lithuanian",
